#!/bin/bash -

cd /tmp/virt-p2v-20180612-2kk3cz75

v2v ()
{
virt-v2v -v -x --colours -i libvirtxml -o "local" -oa sparse -of "raw" -os "/var/tmp" --root first physical.xml </dev/null
# Save the exit code of virt-v2v into the 'status' file.
echo $? > status
}

# Write a pre-emptive error status, in case the virt-v2v
# command doesn't get to run at all.  This will be
# overwritten with the true exit code when virt-v2v runs.
echo 99 > status

log=virt-v2v-conversion-log.txt
rm -f $log

# Log the environment where virt-v2v will run.
printenv > environment

# Log the version of virt-v2v (for information only).
virt-v2v --version > v2v-version

# Run virt-v2v.  Send stdout back to virt-p2v.  Send stdout
# and stderr (debugging info) to the log file.
v2v 2>> $log | tee -a $log

# If virt-v2v failed then the error message (sent to stderr)
# will not be seen in virt-p2v.  Send the last few lines of
# the log back to virt-p2v in this case.
if [ "$(< status)" -ne 0 ]; then
    echo
    echo
    echo
    echo -ne '\e[1;31m'
    echo '***' virt-v2v command failed '***'
    echo
    echo The full log is available on the conversion server in:
    echo '   ' /tmp/virt-p2v-20180612-2kk3cz75/$log
    echo Only the last 50 lines are shown below.
    echo -ne '\e[0m'
    echo
    echo
    echo
    tail -50 $log
fi

# EOF
